#%global tar_version 7.0.7

Name:		openvas-libraries
Summary:	Support libraries for Open Vulnerability Assessment (OpenVAS) Scanner
URL:		http://www.openvas.org
License:	LGPLv2
Group:		System Environment/Libraries
Version:	7.0.7
Release:	1%{?dist}
Source0:	http://wald.intevation.org/frs/download.php/1722/%{name}-%{version}.tar.gz
Source1:	https://svn.wald.intevation.org/svn/openvas/trunk/tools/openvas-check-setup

#Build error use _DEFAULT_SOURCE instead of _BSD_SOURCE
Patch8:		openvas-libraries-bsdsource.patch

#Fix fo newer version of libssh
Patch10:	openvas-libraries-libssh.patch

BuildRoot:	%{_tmppath}/%{name}-%{version}-%{release}-root
Obsoletes:	openvas-libnasl
BuildRequires:	glib2-devel
BuildRequires:	libgcrypt-devel
BuildRequires:	gnutls-devel >= 2.12.10
BuildRequires:	libpcap-devel
BuildRequires:	libuuid-devel
BuildRequires:	libksba-devel
BuildRequires:	gpgme-devel
BuildRequires:	cmake >= 2.6.0
BuildRequires:	bison
BuildRequires:	flex
BuildRequires:	pkgconfig
BuildRequires:	doxygen
BuildRequires:	openldap-devel
BuildRequires:	libssh-devel


%description
openvas-libraries is the base library for the OpenVAS network
security scanner.


%package devel
Summary:	Development files for openvas-libraries
Group:		Development/Libraries
Requires:	%{name} = %{version}-%{release}

%description devel
Development libraries and headers for use with %{name}.


%package doc
Summary:	Documentation for %{name}
Group:		Documentation
Requires:	%{name} = %{version}-%{release}

%description doc
This package contains documentation for %{name}.


%prep
%setup -q -n %{name}-%{tar_version}

#http://kojipkgs.fedoraproject.org//work/tasks/4435/6884435/build.log
#/usr/include/features.h:148:3: error: #warning "_BSD_SOURCE and _SVID_SOURCE are deprecated, use _DEFAULT_SOURCE" [-Werror=cpp]
%if 0%{?fedora} >= 21
%patch8 -p 1 -b .bsdsource
%endif

#Fix for newer version of the libssh
%patch10 -p 1 -b .libssh

#Fix codepage of the Changelog
iconv -f LATIN1 -t UTF8 < ChangeLog > ChangeLog1
mv ChangeLog1 ChangeLog


%build
#export CFLAGS=-Werror=unused-but-set-variable
%cmake -DLOCALSTATEDIR:PATH=%{_var} -DBUILD_WITH_LDAP=ON
# No parallel build because it causes compilation problems
make
make doc

%install
rm -rf %{buildroot}
make install DESTDIR=%{buildroot} INSTALL="install -p"
find %{buildroot} -name '*.la' -exec rm -f {} ';'

# Remove static libraries
find %{buildroot} -name '*.a' -exec rm -f {} ';'

# Currently I don't know for what is this used so I removing it
rm -f %{buildroot}/%{_datadir}/openvas/openvas-lsc-rpm-creator.sh

#Install openvas-check-setup
install -m 755 %{SOURCE1} %{buildroot}%{_bindir}/

%post -p /sbin/ldconfig
%postun -p /sbin/ldconfig

%clean
rm -rf %{buildroot}

%files
%defattr(-,root,root,-)
%doc README COPYING* ChangeLog CHANGES
%dir %{_datadir}/openvas
%dir %{_sysconfdir}/openvas
%{_bindir}/openvas-nasl
%{_bindir}/openvas-nasl-lint
%{_bindir}/openvas-check-setup
%{_mandir}/man1/openvas-nasl.1.*
%{_libdir}/libopenvas_base.so.*
#%{_libdir}/libopenvas_hg.so.*
%{_libdir}/libopenvas_misc.so.*
%{_libdir}/libopenvas_nasl.so.*
%{_libdir}/libopenvas_omp.so.*
#%{_datadir}/openvas/openvas-services

%files devel
%defattr(-,root,root,-)
%{_includedir}/openvas/
%{_libdir}/libopenvas_base.so
#%{_libdir}/libopenvas_hg.so
%{_libdir}/libopenvas_misc.so
%{_libdir}/libopenvas_nasl.so
%{_libdir}/libopenvas_omp.so
%{_libdir}/pkgconfig/libopenvas.pc

%files doc
%defattr(-,root,root,-)
%doc doc/generated/html
%doc doc/example.auth.conf
%doc doc/example.target.locators
%doc doc/signatures-howto.txt
%doc doc/test_ipv6_packet_forgery.nasl
%doc doc/wmi-howto.txt


%changelog
* Thu Jan 29 2015 josef radinger <cheese@nosuchhost.net> - 7.0.7-1
- bump version

* Fri Nov 28 2014 josef radinger <cheese@nosuchhost.net> - 7.0.6-3
- bump version
- resync

* Mon Nov 10 2014 josef radinger <cheese@nosuchhost.net> - 7.0.5-2
- rebuild

* Fri Nov 07 2014 josef radinger <cheese@nosuchhost.net> - 7.0.5-1
- bump version
- DEFAULT_SOURCE for fc20 onwards

* Tue Sep 09 2014 josef radinger <cheese@nosuchhost.net> - 7.0.4-1
- bump version

* Mon Aug 04 2014 josef radinger <cheese@nosuchhost.net> - 7.0.3-1
- bump version

* Mon Jun 16 2014 josef radinger <cheese@nosuchhost.net> - 7.0.2-1
- bump version
- remove patch1

* Tue May 27 2014 josef radinger <cheese@nosuchhost.net> - 7.0.1-10
- rebuild

* Sat May 3 2014 Scott R. Shinn <scott@atomicorp.com> - 7.0.1-9
- Update to 7.0.1

* Fri Feb 28 2014 Scott R. Shinn <scott@atomicorp.com> - 6.0.2-8
- Update to 6.0.2

* Fri Oct 25 2013 Scott R. Shinn <scott@atomicorp.com> - 6.0.1-7
- Update to 6.0.1

* Thu Apr 18 2013 Scott R. Shinn <scott@atomicorp.com> - 6.0.0-6
- Update to 6.0.0
- Remove el4 references 

* Wed Nov 07 2012 Scott R. Shinn <scott@atomicorp.com> - 5.0.4-5
- Update to 5.0.4

* Mon Aug 20 2012 Scott R. Shinn <scott@atomicorp.com> - 5.0.3-4
- Update to 5.0.3 

* Wed Jul 25 2012 Scott R. Shinn <scott@atomicorp.com> - 5.0.1-3
- Backport fix for gnutls 2.17 support

* Thu May 10 2012 Scott R. Shinn <scott@atomicorp.com> - 5.0.1-2
- Update to 5.0.1

* Tue Apr 24 2012 Scott R. Shinn <scott@atomicorp.com> - 5.0.0-1
- Update to 5.0.0
- Add in documentation package

* Mon Nov 7 2011 Scott R. Shinn <scott@atomicorp.com> - 4.0.6-3
- Bugfix #XXX, correct md5sum for the lsc rpm creation script

* Fri Nov 4 2011 Scott R. Shinn <scott@atomicorp.com> - 4.0.6-1
- Update to 4.0.6

* Wed Jun 1 2011 Scott R. Shinn <scott@atomicorp.com> - 4.0.5-1
- Update to 4.0.5

* Wed May 4 2011 Scott R. Shinn <scott@atomicorp.com> - 4.0.4-1
- Update to 4.0.4

* Mon Mar 7 2011 Scott R. Shinn <scott@atomicorp.com> - 4.0.3-1
- Update to 4.0.3

* Tue Feb 23 2011 Scott R. Shinn <scott@atomicorp.com> - 4.0.2-1
- Update to 4.0.2
- Happy 40th Mike!

* Tue Feb 22 2011 Scott R. Shinn <scott@atomicorp.com> - 4.0.1-1
- Update to 4.0.1

* Thu Feb 3 2011 Scott R. Shinn <scott@atomicorp.com> - 4.0.0-1
- Update to 4.0 final

* Wed Jan 19 2011 Scott R. Shinn <scott@atomicorp.com> - 4.0-0.3
- Update to 4.0-rc2

* Wed Dec 29 2010 Scott R. Shinn <scott@atomicorp.com> - 4.0-0.2
- Update to 4.0-rc1

* Fri Dec 3 2010 Scott R. Shinn <scott@atomicorp.com> - 4.0-beta2 
- Update to 4.0-beta2

* Sun Oct 17 2010 Scott R. Shinn <scott@atomicorp.com> - 3.1.3-2
- Rebuild libraries with wmi support

* Fri Sep 10 2010 Scott R. Shinn <scott@atomicorp.com> - 3.1.3-1
- Update to 3.1.3

* Thu Aug 26 2010 Scott R. Shinn <scott@atomicorp.com> - 3.1.2-1
- Update to 3.1.2

* Thu Jul 1 2010 Scott R. Shinn <scott@atomicorp.com> - 3.1.0-3
- Update to 3.1.0rc3

* Mon Jun 28 2010 Scott R. Shinn <scott@atomicorp.com> - 3.1.0-2
- Update to 3.1.0rc2

* Wed May 19 2010 Scott R. Shinn <scott@atomicorp.com> - 3.1.0-1
- Update to 3.1.0rc1

* Tue Apr 11 2010 Scott R. Shinn <scott@atomicorp.com> - 3.0.5-1
- Update to 3.0.5

* Wed Mar 3 2010 Scott R. Shinn <scott@atomicorp.com> - 3.0.4-1
- Update to 3.0.4

* Mon Feb 4 2010 Scott R. Shinn <scott@atomicorp.com> - 3.0.3-1
- Update to 3.0.3

* Mon Jan 11 2010 Scott R. Shinn <scott@atomicorp.com> - 3.0.1-1
- Update to 3.0.1

* Fri Dec 18 2009 Scott R. Shinn <scott@atomicrocketturtle.com> - 3.0.0-1
- Update to 3.0.0

* Tue Aug 18 2009 Scott R. Shinn <scott@atomicrocketturtle.com> - 2.0.4-1
- Update to 2.0.4

* Thu Jun 11 2009 Scott R. Shinn <scott@atomicrocketturtle.com> - 2.0.3-1
- Update to 2.0.3

* Fri Mar 6 2009 Scott R. Shinn <scott@atomicrocketturtle.com> - 2.0.2-1
- Update to 2.0.2

* Mon Feb 9 2009 Scott R. Shinn <scott@atomicrocketturtle.com> - 2.0.1-1
- Update to 2.0.1

* Tue Dec 30 2008 Scott R. Shinn <scott@atomicrocketturtle.com> - 2.0.0-2
- Bugfix #XXX, added libtoolize before configure

* Mon Dec 22 2008 Scott R. Shinn <scott@atomicrocketturtle.com> - 2.0.0
- Update to 2.0.0

* Thu Dec 11 2008 Scott R. Shinn <scott@atomicrocketturtle.com> - 2.0.0.rc1
- Update to 2.0.0.rc1

* Mon Nov 17 2008 Scott R. Shinn <scott@atomicrocketturtle.com> - 2.0.0.beta2-1
- Update to 2.0.0.beta2
 
* Fri Nov 7 2008 Scott R. Shinn <scott@atomicrocketturtle.com> - 2.0.0.beta1-1
- Update to 2.0.0.beta1

* Wed Nov 5 2008 Scott R. Shinn <scott@atomicrocketturtle.com> - 1.0.2-1
- Update to 1.0.2
- Merge into Atomic

* Fri Apr 18 2008 Jan-Oliver Wagner <jan-oliver.wagner@intevation.de>
  - Adapated for Fedora 8 (naming)
  - %post and %postrun changed to apply ldconfig directly instead of using
    a (SUSE specific?) scriplet.
  - extended BuildRequires with libpcap-devel
* Tue Apr 15 2008 Jan-Oliver Wagner <jan-oliver.wagner@intevation.de>
  Initial SUSE 10.2 spec file, tested for i586
